summaryrefslogtreecommitdiffstats
path: root/mandoline/ui/phone_ui
diff options
context:
space:
mode:
authorfsamuel <fsamuel@chromium.org>2015-10-15 17:12:45 -0700
committerCommit bot <commit-bot@chromium.org>2015-10-16 00:13:20 +0000
commit68afcf453d29c8f311b34a0aa210e042d4adc132 (patch)
tree5d7e25e02abe745aec485ecb4450f37d24b080c8 /mandoline/ui/phone_ui
parentda33ab883a2046613836487d852d5fd36f1dc4c3 (diff)
downloadchromium_src-68afcf453d29c8f311b34a0aa210e042d4adc132.zip
chromium_src-68afcf453d29c8f311b34a0aa210e042d4adc132.tar.gz
chromium_src-68afcf453d29c8f311b34a0aa210e042d4adc132.tar.bz2
View => Window in components/mus/public/cpp
This CL updates the client lib to refer to mus::Windows and mus::WindowServer instead of View and View Manager. I hope I caught everything. I'll clean things up in subsequent CLs, and start renaming the interfaces and implementation. BUG=542848 Review URL: https://codereview.chromium.org/1402223003 Cr-Commit-Position: refs/heads/master@{#354411}
Diffstat (limited to 'mandoline/ui/phone_ui')
-rw-r--r--mandoline/ui/phone_ui/phone_browser_application_delegate.cc22
-rw-r--r--mandoline/ui/phone_ui/phone_browser_application_delegate.h26
2 files changed, 24 insertions, 24 deletions
diff --git a/mandoline/ui/phone_ui/phone_browser_application_delegate.cc b/mandoline/ui/phone_ui/phone_browser_application_delegate.cc
index d2ac75b..ef3758d 100644
--- a/mandoline/ui/phone_ui/phone_browser_application_delegate.cc
+++ b/mandoline/ui/phone_ui/phone_browser_application_delegate.cc
@@ -5,9 +5,9 @@
#include "mandoline/ui/phone_ui/phone_browser_application_delegate.h"
#include "base/command_line.h"
-#include "components/mus/public/cpp/view.h"
-#include "components/mus/public/cpp/view_tree_connection.h"
-#include "components/mus/public/cpp/view_tree_host_factory.h"
+#include "components/mus/public/cpp/window.h"
+#include "components/mus/public/cpp/window_tree_connection.h"
+#include "components/mus/public/cpp/window_tree_host_factory.h"
#include "mojo/application/public/cpp/application_connection.h"
#include "mojo/application/public/cpp/application_impl.h"
#include "mojo/converters/geometry/geometry_type_converters.h"
@@ -47,7 +47,7 @@ void PhoneBrowserApplicationDelegate::Initialize(mojo::ApplicationImpl* app) {
break;
}
}
- mus::CreateSingleViewTreeHost(app_, this, &host_);
+ mus::CreateSingleWindowTreeHost(app_, this, &host_);
}
bool PhoneBrowserApplicationDelegate::ConfigureIncomingConnection(
@@ -66,12 +66,12 @@ void PhoneBrowserApplicationDelegate::LaunchURL(const mojo::String& url) {
}
////////////////////////////////////////////////////////////////////////////////
-// PhoneBrowserApplicationDelegate, mus::ViewTreeDelegate implementation:
+// PhoneBrowserApplicationDelegate, mus::WindowTreeDelegate implementation:
-void PhoneBrowserApplicationDelegate::OnEmbed(mus::View* root) {
+void PhoneBrowserApplicationDelegate::OnEmbed(mus::Window* root) {
CHECK(!root_);
root_ = root;
- content_ = root->connection()->CreateView();
+ content_ = root->connection()->CreateWindow();
root->AddChild(content_);
content_->SetBounds(root->bounds());
content_->SetVisible(true);
@@ -83,13 +83,13 @@ void PhoneBrowserApplicationDelegate::OnEmbed(mus::View* root) {
}
void PhoneBrowserApplicationDelegate::OnConnectionLost(
- mus::ViewTreeConnection* connection) {}
+ mus::WindowTreeConnection* connection) {}
////////////////////////////////////////////////////////////////////////////////
-// PhoneBrowserApplicationDelegate, mus::ViewObserver implementation:
+// PhoneBrowserApplicationDelegate, mus::WindowObserver implementation:
-void PhoneBrowserApplicationDelegate::OnViewBoundsChanged(
- mus::View* view,
+void PhoneBrowserApplicationDelegate::OnWindowBoundsChanged(
+ mus::Window* view,
const mojo::Rect& old_bounds,
const mojo::Rect& new_bounds) {
CHECK_EQ(view, root_);
diff --git a/mandoline/ui/phone_ui/phone_browser_application_delegate.h b/mandoline/ui/phone_ui/phone_browser_application_delegate.h
index f310259..e21c225 100644
--- a/mandoline/ui/phone_ui/phone_browser_application_delegate.h
+++ b/mandoline/ui/phone_ui/phone_browser_application_delegate.h
@@ -7,8 +7,8 @@
#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
-#include "components/mus/public/cpp/view_observer.h"
-#include "components/mus/public/cpp/view_tree_delegate.h"
+#include "components/mus/public/cpp/window_observer.h"
+#include "components/mus/public/cpp/window_tree_delegate.h"
#include "components/mus/public/interfaces/view_tree_host.mojom.h"
#include "components/web_view/public/cpp/web_view.h"
#include "components/web_view/public/interfaces/web_view.mojom.h"
@@ -27,8 +27,8 @@ namespace mandoline {
class PhoneBrowserApplicationDelegate
: public mojo::ApplicationDelegate,
public LaunchHandler,
- public mus::ViewTreeDelegate,
- public mus::ViewObserver,
+ public mus::WindowTreeDelegate,
+ public mus::WindowObserver,
public web_view::mojom::WebViewClient,
public mojo::InterfaceFactory<LaunchHandler> {
public:
@@ -44,14 +44,14 @@ class PhoneBrowserApplicationDelegate
// Overridden from LaunchHandler:
void LaunchURL(const mojo::String& url) override;
- // Overridden from mus::ViewTreeDelegate:
- void OnEmbed(mus::View* root) override;
- void OnConnectionLost(mus::ViewTreeConnection* connection) override;
+ // Overridden from mus::WindowTreeDelegate:
+ void OnEmbed(mus::Window* root) override;
+ void OnConnectionLost(mus::WindowTreeConnection* connection) override;
- // Overridden from mus::ViewObserver:
- void OnViewBoundsChanged(mus::View* view,
- const mojo::Rect& old_bounds,
- const mojo::Rect& new_bounds) override;
+ // Overridden from mus::WindowObserver:
+ void OnWindowBoundsChanged(mus::Window* view,
+ const mojo::Rect& old_bounds,
+ const mojo::Rect& new_bounds) override;
// Overridden from web_view::mojom::WebViewClient:
void TopLevelNavigateRequest(mojo::URLRequestPtr request) override;
@@ -73,8 +73,8 @@ class PhoneBrowserApplicationDelegate
mojo::ApplicationImpl* app_;
mojo::ViewTreeHostPtr host_;
- mus::View* root_;
- mus::View* content_;
+ mus::Window* root_;
+ mus::Window* content_;
web_view::WebView web_view_;
mojo::String default_url_;